==> haskell-findbin-0.0.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FindBin
version:              0.0.5
visibility:           public
id:                   FindBin-0.0.5-6WKfNqvNmZPDerAGSsIF9J
key:                  FindBin-0.0.5-6WKfNqvNmZPDerAGSsIF9J
license:              BSD-3-Clause
copyright:            2008-2011 Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang <audreyt@audreyt.org>
stability:            Stable
homepage:             https://github.com/audreyt/findbin
synopsis:             Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.

category:             System
abi:                  b2a23e1837cb5d91119e530e83f982a8
exposed:              True
exposed-modules:      System.Environment.FindBin
import-dirs:          /usr/lib/ghc-8.10.1/site-local/FindBin-0.0.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/FindBin-0.0.5
hs-libraries:         HSFindBin-0.0.5-6WKfNqvNmZPDerAGSsIF9J
depends:              base-4.14.0.0 directory-1.3.6.0 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html:         /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-findbin-0.0.5-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FindBin
version:              0.0.5
visibility:           public
id:                   FindBin-0.0.5-5lJl2V0d37y8FwE9uJ8t4E
key:                  FindBin-0.0.5-5lJl2V0d37y8FwE9uJ8t4E
license:              BSD-3-Clause
copyright:            2008-2011 Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang <audreyt@audreyt.org>
stability:            Stable
homepage:             https://github.com/audreyt/findbin
synopsis:             Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.

category:             System
abi:                  983c991e7c39612771579d6d32555a67
exposed:              True
exposed-modules:      System.Environment.FindBin
import-dirs:          /usr/lib/ghc-8.10.3/site-local/FindBin-0.0.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/FindBin-0.0.5
hs-libraries:         HSFindBin-0.0.5-5lJl2V0d37y8FwE9uJ8t4E
depends:              base-4.14.1.0 directory-1.3.6.0 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html:         /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
